'use strict';

Object.defineProperty(exports, '__esModule', {
  value: true
});

var typography = require('@highlight-ui/typography');

var utilsCommons = require('@highlight-ui/utils-commons');

var utilsHooks = require('@highlight-ui/utils-hooks');

var utilsPortalManager = require('@highlight-ui/utils-portal-manager');

var classnames = require('classnames');

var React = require('react');

function _interopDefaultLegacy(e) {
  return e && typeof e === 'object' && 'default' in e ? e : {
    'default': e
  };
}

var classnames__default = /*#__PURE__*/_interopDefaultLegacy(classnames);

var React__default = /*#__PURE__*/_interopDefaultLegacy(React);
/*! *****************************************************************************
Copyright (c) Microsoft Corporation.

Permission to use, copy, modify, and/or distribute this software for any
purpose with or without fee is hereby granted.

THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
PERFORMANCE OF THIS SOFTWARE.
***************************************************************************** */


var __assign = function () {
  __assign = Object.assign || function __assign(t) {
    for (var s, i = 1, n = arguments.length; i < n; i++) {
      s = arguments[i];

      for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p)) t[p] = s[p];
    }

    return t;
  };

  return __assign.apply(this, arguments);
};

var styles = {
  "offsetVarName": "--tooltip-offset",
  "tooltip": "Tooltip-module__Qg97SOst__v3-2-1",
  "trigger": "Tooltip-module__3sgODyUy__v3-2-1"
};
/* eslint-disable no-param-reassign */

function clearTooltipTimers() {
  var timers = [];

  for (var _i = 0; _i < arguments.length; _i++) {
    timers[_i] = arguments[_i];
  }

  timers.forEach(function (t) {
    clearTimeout(t.current);
    t.current = null;
  });
}

var delayValues = {
  medium: 375,
  long: 1000
};

function useTooltipVisibility(mouseEnterDelay, mouseOutDelay, interactive) {
  var timerToShow = React.useRef(null);
  var timerToHide = React.useRef(null);

  var _a = React.useState(false),
      isVisible = _a[0],
      setIsVisible = _a[1];

  function updateVisibility(newValue, timer, delay) {
    if (delay === 'none') {
      setIsVisible(newValue);
    } else {
      timer.current = setTimeout(function () {
        return setIsVisible(newValue);
      }, delayValues[delay]);
    }
  }

  function handleTriggerMouseOver() {
    clearTooltipTimers(timerToShow, timerToHide);
    if (!isVisible) updateVisibility(true, timerToShow, mouseEnterDelay);
  }

  function handleMouseLeave() {
    clearTooltipTimers(timerToShow, timerToHide);
    if (isVisible) updateVisibility(false, timerToHide, mouseOutDelay);
  }

  function handleTooltipMouseEnter() {
    if (interactive) {
      clearTooltipTimers(timerToHide);
    }
  }

  React.useEffect(function () {
    // cleanup on unmount
    return function () {
      return clearTooltipTimers(timerToShow, timerToHide);
    };
  }, []);
  return [isVisible, handleTriggerMouseOver, handleTooltipMouseEnter, handleMouseLeave];
}

var Tooltip = function (_a) {
  var propsId = _a.id,
      children = _a.children,
      content = _a.content,
      _b = _a.mouseEnterDelay,
      mouseEnterDelay = _b === void 0 ? 'none' : _b,
      _c = _a.mouseOutDelay,
      mouseOutDelay = _c === void 0 ? 'none' : _c,
      metadata = _a.metadata,
      _d = _a.interactive,
      interactive = _d === void 0 ? false : _d,
      _e = _a.placement,
      placement = _e === void 0 ? 'top' : _e;

  var _f = useTooltipVisibility(mouseEnterDelay, mouseOutDelay, interactive),
      isVisible = _f[0],
      handleTriggerMouseOver = _f[1],
      handleTooltipMouseEnter = _f[2],
      handleMouseLeave = _f[3];

  var uid = utilsHooks.useId('tooltip-');
  var id = propsId || uid;
  var modifiers = [];
  var definedOffset = getComputedStyle(document.documentElement).getPropertyValue(styles.offsetVarName);

  if (definedOffset) {
    modifiers.push({
      name: 'offset',
      options: {
        offset: [0, parseInt(definedOffset, 10)]
      }
    });
  }

  var _g = utilsHooks.useAutoPositioner({
    placement: placement,
    modifiers: modifiers
  }),
      setReferenceElement = _g.setReferenceElement,
      setPopperElement = _g.setPopperElement,
      popperStyles = _g.styles.popper,
      attributes = _g.attributes;

  var childRef = utilsHooks.useForkRef([setReferenceElement, // TODO: Get rid of any type when working on PPUI-357
  children.ref]);
  return React__default["default"].createElement(React__default["default"].Fragment, null, React.cloneElement(children, __assign({
    className: classnames__default["default"](children.props.className, styles.trigger),
    ref: childRef,
    onMouseOver: utilsCommons.forkHandlers([content ? handleTriggerMouseOver : null, children.props.onMouseOver]),
    onMouseLeave: utilsCommons.forkHandlers([content ? handleMouseLeave : null, children.props.onMouseLeave])
  }, utilsCommons.parseMetadata(metadata))), content && isVisible && React__default["default"].createElement(utilsPortalManager.GroupedPortal, null, React__default["default"].createElement("div", __assign({
    role: "tooltip",
    className: styles.tooltip,
    id: id,
    ref: setPopperElement,
    style: popperStyles,
    onMouseEnter: handleTooltipMouseEnter,
    onMouseLeave: handleMouseLeave
  }, attributes.popper), React__default["default"].createElement(typography.Typography, {
    token: "body-base",
    component: "span"
  }, content))));
};

exports.Tooltip = Tooltip;
//# sourceMappingURL=index.js.map
